@@ -172,6 +172,7 @@ public class ParserConfig extends RubyObject {
 
     @JRubyMethod(visibility = Visibility.PRIVATE)
     public IRubyObject initialize(ThreadContext context, IRubyObject options) {
+        checkFrozen();
         Ruby runtime = context.runtime;
 
         OptionsReader opts   = new OptionsReader(context, options);
@@ -2125,10 +2126,10 @@ case 1:
                         if (((RubyHash)result).hasKey(lastName)) {
                             if (config.deprecateDuplicateKey) {
                                 context.runtime.getWarnings().warning(
-                                    "detected duplicate keys in JSON object. This will raise an error in json 3.0 unless enabled via `allow_duplicate_key: true`"
+                                    "detected duplicate key " + name.inspect() + " in JSON object. This will raise an error in json 3.0 unless enabled via `allow_duplicate_key: true`"
                                 );
                             } else {
-                                throw parsingError(context, "duplicate key", p, pe);
+                                throw parsingError(context, "duplicate key" + name.inspect(), p, pe);
                             }
                         }
                     }
